Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'release/scripts/templates/gamelogic_module.py')
-rw-r--r--release/scripts/templates/gamelogic_module.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/release/scripts/templates/gamelogic_module.py b/release/scripts/templates/gamelogic_module.py
index 5a61a3592dc..fcc8a8839c9 100644
--- a/release/scripts/templates/gamelogic_module.py
+++ b/release/scripts/templates/gamelogic_module.py
@@ -5,13 +5,14 @@
# * External text modules are supported as long as they are at
# the same location as the blendfile or one of its libraries.
-import GameLogic
+import bge
# variables defined here will only be set once when the
# module is first imported. Set object spesific vars
# inside the function if you intend to use the module
# with multiple objects.
+
def main(cont):
own = cont.owner
@@ -23,4 +24,4 @@ def main(cont):
else:
cont.deactivate(actu)
# dont call main(GameLogic.getCurrentController()), the py controller will
@@ -23,4 +24,4 @@ def main(cont):
else:
cont.deactivate(actu)
-# dont call main(GameLogic.getCurrentController()), the py controller will
+# dont call main(bge.logic.getCurrentController()), the py controller will